.. _Python Programming Language: http://www.python.org/
.. _Python Standard Library: http://docs.python.org/library/
.. _MIT License: http://www.opensource.org/licenses/mit-license.php
.. _rbtranslations Page on PyPI: http://pypi.python.org/pypi/rbtranslations
.. _Package Documentation: http://packages.python.org/rbtranslations
.. _github: https://github.com/mnlipp/ResourceBundleTranslations
.. _issue tracker: https://github.com/mnlipp/ResourceBundleTranslations/issues 

Overview
--------

rbtranslations is an alternative approach to managing localized
messages in a Python application. Read the `Package Documentation`_
for details.

The source is maintained at `github`_. Please use the `issue tracker`_ 
there to report any issues.

Requirements
------------

rbtranslations has no dependencies beyond the `Python Standard Library`_.

Installation
------------

The simplest and recommended way to install rbtranslations is with 
easy_install::

    > easy_install rbtranslations

Alternatively, you may download the source package from the
`rbtranslations Page on PyPI`_ or from `github`_, extract it 
and install using::

    > python setup.py install

License
-------

rbtranslations is licensed under the `MIT License`_.

